@@ -5,8 +5,8 @@ from threading import Lock
 
 import numpy as np
 
-from PyQt4.QtGui import *
-from PyQt4.QtCore import *
+from AnyQt.QtCore import QTimer, QSize, Qt
+from AnyQt.QtWidgets import QWidget, QListWidget, QFileDialog
 
 import Orange
 from Orange.util import scale
@@ -110,6 +110,15 @@ class OWNxExplorer(widget.OWWidget):
 
     graph_name = 'view'
 
+    class Warning(widget.OWWidget.Warning):
+        distance_matrix_size = widget.Msg("Distance matrix size doesn't match the number of network nodes. Not using it.")
+        no_graph_found = widget.Msg('No graph found!')
+        no_graph_or_items = widget.Msg('No graph provided or no items attached to the graph.')
+
+    class Error(widget.OWWidget.Error):
+        instance_for_each_node = widget.Msg('Items table must have one instance for each network node.')
+        network_too_large = widget.Msg('Network is too large to visualize. Sorry.')
+
     def __init__(self):
         super().__init__()
         #self.contextHandlers = {"": DomainContextHandler("", [ContextField("attributes", selected="node_label_attrs"), ContextField("attributes", selected="tooltipAttributes"), "color"])}
@@ -310,22 +319,22 @@ class OWNxExplorer(widget.OWWidget):
             self.view.setHighlighted(neighbors)
         elif selectionMode == SelectionMode.AT_LEAST_N:
             self.view.setHighlighted(
-                set(node for node, degree in self.graph.degree().items()
+                set(node for node, degree in self.graph.degree()
                     if degree >= self.markNConnections))
         elif selectionMode == SelectionMode.AT_MOST_N:
             self.view.setHighlighted(
-                set(node for node, degree in self.graph.degree().items()
+                set(node for node, degree in self.graph.degree()
                     if degree <= self.markNConnections))
         elif selectionMode == SelectionMode.ANY_NEIGH:
             self.view.setHighlighted(
-                set(node for node, degree in self.graph.degree().items()
-                    if degree > max(self.graph.degree(self.graph[node]).values(), default=0)))
+                set(node for node, degree in self.graph.degree()
+                    if degree > max(dict(self.graph.degree(self.graph[node])).values(), default=0)))
         elif selectionMode == SelectionMode.AVG_NEIGH:
             self.view.setHighlighted(
-                set(node for node, degree in self.graph.degree().items()
-                    if degree > np.nan_to_num(np.mean(list(self.graph.degree(self.graph[node]).values())))))
+                set(node for node, degree in self.graph.degree()
+                    if degree > np.nan_to_num(np.mean(list(dict(self.graph.degree(self.graph[node])).values())))))
         elif selectionMode == SelectionMode.MOST_CONN:
-            degrees = np.array(sorted(self.graph.degree().items(), key=lambda i: i[1], reverse=True))
+            degrees = np.array(sorted(self.graph.degree(), key=lambda i: i[1], reverse=True))
             cut_ind = max(1, min(self.markNBest, self.graph.number_of_nodes()))
             cut_degree = degrees[cut_ind - 1, 1]
             toMark = set(degrees[degrees[:, 1] >= cut_degree, 0])
@@ -334,7 +343,7 @@ class OWNxExplorer(widget.OWWidget):
             tomark = {}
             if self.markInputItems:
                 ids = set(self.markInputItems.ids)
-                tomark = {x for x in self.graph.nodes()
+                tomark = {x for x in self.graph
                           if self.graph.items()[x].id in ids}
             self.view.setHighlighted(tomark)
 
@@ -414,13 +423,6 @@ class OWNxExplorer(widget.OWWidget):
 
             if var.is_continuous:
                 self.nodeSizeCombo.addItem(gui.attributeIconDict[gui.vartype(var)], var.name, var)
-            elif var.is_string:
-                try: value = self.graph.items()[0][var].value
-                except (IndexError, TypeError): pass
-                else:
-                    # can value be a list?
-                    if len(value.split(',')) > 1:
-                        self.nodeSizeCombo.addItem(gui.attributeIconDict[gui.vartype(var)], var.name, var)
 
         self.nodeSizeCombo.setDisabled(not self.graph_attrs)
         self.colorCombo.setDisabled(not self.graph_attrs)
@@ -438,16 +440,28 @@ class OWNxExplorer(widget.OWWidget):
                 self.set_node_colors()
                 break
 
-        for i in range(self.attListBox.count()):
-            if str(self.attListBox.item(i).text()) in lastLabelColumns:
-                self.attListBox.item(i).setSelected(True)
+        if lastLabelColumns:
+            selection = QItemSelection()
+            model = self.attListBox.model()
+            for i in range(self.attListBox.count()):
+                if str(self.attListBox.item(i).text()) in lastLabelColumns:
+                    selection.append(QItemSelectionRange(model.index(i, 0)))
+            selmodel = self.attListBox.selectionModel()
+            selmodel.select(selection, selmodel.Select | selmodel.Clear)
+        else:
+            self.attListBox.selectionModel().clearSelection()
         self._on_node_label_attrs_changed()
 
-        for i in range(self.tooltipListBox.count()):
-            if (self.tooltipListBox.item(i).text() in lastTooltipColumns or
-                not lastTooltipColumns):
-                self.tooltipListBox.item(i).setSelected(True)
-
+        if lastTooltipColumns:
+            selection = QItemSelection()
+            model = self.tooltipListBox.model()
+            for i in range(self.tooltipListBox.count()):
+                if self.tooltipListBox.item(i).text() in lastTooltipColumns:
+                    selection.append(QItemSelectionRange(model.index(i, 0)))
+            selmodel = self.tooltipListBox.selectionModel()
+            selmodel.select(selection, selmodel.Select | selmodel.Clear)
+        else:
+            self.tooltipListBox.selectionModel().clearSelection()
         self._clicked_tooltip_lstbox()
 
         self.lastLabelColumns = lastLabelColumns
@@ -482,11 +496,11 @@ class OWNxExplorer(widget.OWWidget):
             return
         if graph.number_of_nodes() + graph.number_of_edges() > 30000:
             self.set_graph_none()
-            self.error('Network is too large to visualize. Sorry.')
+            self.Error.network_too_large()
             return
         self.information()
 
-        all_edges_equal = bool(1 == len(set(w for u,v,w in graph.edges_iter(data='weight'))))
+        all_edges_equal = bool(1 == len(set(w for u,v,w in graph.edges(data='weight'))))
         self.checkbox_show_weights.setEnabled(not all_edges_equal)
         self.checkbox_relative_edges.setEnabled(not all_edges_equal)
 
@@ -504,7 +518,7 @@ class OWNxExplorer(widget.OWWidget):
         self.edgesPerVertex = self.graph.number_of_edges() / max(1, self.graph.number_of_nodes())
 
         self._set_combos()
-        self.error()
+        self.Error.clear()
 
         self.set_selection_mode()
         self.relayout()
@@ -514,13 +528,13 @@ class OWNxExplorer(widget.OWWidget):
         if items is None:
             return self.set_graph(self.graph_base)
         if not self.graph:
-            self.warning('No graph found!')
+            self.Warning.no_graph_found()
             return
-        self.warning()
+        self.Warning.clear()
         if len(items) != self.graph.number_of_nodes():
-            self.error('Items table must have one instance for each network node.')
+            self.Error.instance_for_each_node()
             return
-        self.error()
+        self.Error.instance_for_each_node.clear()
         self.graph.set_items(items)
         self._set_combos()
 
@@ -528,14 +542,14 @@ class OWNxExplorer(widget.OWWidget):
         self.markInputRadioButton.setEnabled(False)
         self.markInputItems = items
 
-        self.warning()
+        self.Warning.clear()
 
         if items is None:
             self.view.selectionChanged.emit()
             return
 
         if self.graph is None or self.graph.items() is None:
-            self.warning('No graph provided or no items attached to the graph.')
+            self.Warning.no_graph_or_items()
             return
 
         graph_items = self.graph.items()
@@ -557,9 +571,9 @@ class OWNxExplorer(widget.OWWidget):
 
         distmatrix = self.items_matrix
         if distmatrix is not None and distmatrix.shape[0] != self.graph.number_of_nodes():
-            self.warning(17, "Distance matrix size doesn't match the number of network nodes. Not using it.")
+            self.Warning.distance_matrix_size()
             distmatrix = None
-        self.warning(17)
+        self.Warning.distance_matrix_size.clear()
 
         self.relayout_button.setDisabled(True)
         self.view.relayout(randomize=False, weight=distmatrix)
@@ -595,7 +609,7 @@ class OWNxExplorer(widget.OWWidget):
 
     def set_edge_labels(self):
         if self.showEdgeWeights:
-            weights = (str(w or '') for u, v, w in self.graph.edges_iter(data='weight'))
+            weights = (str(w or '') for u, v, w in self.graph.edges(data='weight'))
         else:
             weights = ('' for i in range(self.graph.number_of_edges()))
         for edge, weight in zip(self.view.edges, weights):
@@ -648,10 +662,6 @@ class OWNxExplorer(widget.OWWidget):
                 node.setSize(self.minNodeSize)
             return
 
-        if isinstance(table.domain[attribute], StringVariable):
-            values = np.array([(s.count(',') + 1) if s else np.nan
-                               for s in values])
-
         if self.invertNodeSize:
             values += np.nanmin(values) + 1
             values = 1/values
@@ -670,7 +680,7 @@ class OWNxExplorer(widget.OWWidget):
     def set_edge_sizes(self):
         if not self.graph: return
         if self.relativeEdgeWidths:
-            widths = [self.graph.edge[u][v].get('weight', 1)
+            widths = [self.graph.adj[u][v].get('weight', 1)
                       for u, v in self.graph.edges()]
             widths = scale(widths, .7, 8)
         else:
@@ -696,6 +706,7 @@ class OWNxExplorer(widget.OWWidget):
 
 
 if __name__ == "__main__":
+    from AnyQt.QtWidgets import QApplication
     import sys
     a = QApplication(sys.argv)
     ow = OWNxExplorer()
